@@ -184,7 +184,7 @@ def plot_backgrounds(backgrounds, bins, *, total_err=None, ax=None):
         if len(bkg.hist) != len(total_stat_err):
             raise BinningMismatchError(f"Invalid binning for background {i}")
         total_stat_err += _np.square(bkg.stat_errs)
-        if total_err is not None:
+        if total_err is None:
             total_syst_err += _np.square(bkg.syst_errs)
         total_hist += bkg.hist
     # components still variances at this point
